@@ -13,3 +13,5 @@ class DataSourceType:
     MYSQL = 'mysql'
     POSTGRES = 'postgres'
     SQLSERVER = 'sqlserver'
+    KAFKA = 'kafka'
+    ELASTICSEARCH = 'es'
